@@ -24,7 +24,6 @@ class Tile:
                 r"(?P<orbit>(\d{6}))_"
                 r"(?P<mission>[A-Z0-9]{6})_"
                 r"(?P<pid>[A-Z0-9]{4})"
-                r"\.SAFE$"
             )
 
         match = re.match(pattern, self.path.name, re.IGNORECASE)
@@ -54,6 +53,3 @@ class Tile:
     def stop(self):
         return datetime.datetime.strptime(self.props["stop"], "%Y%m%dT%H%M%S")
 
-    def get_band(self, polarization):
-        tif = next(self.path.glob(f"measurement/*-{polarization.name.lower()}-*.tiff"))
-        return tif
